/***************************************************************************
Copyright (c) 2006 Peter Korzuszek, KateOS Project
 
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 
*Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
 
*Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS
IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE. 
****************************************************************************/

#ifndef SMART_TOOLS_SCRIPT_H
#define SMART_TOOLS_SCRIPT_H

#include "stfile.h"
#include "smarttools.h"
#include "ststringlist.h"
#include "stapplication.h"

/*!
	\brief This class allows keeping scripts in memory for execution later.
	
	This is very useful if you want write your own script and execute it
	at once. You can also load existing scripts from a file, edit, and then
	execute it or save it.
	
	\warning You must be beware to call setTempDirectory() before using
		execute() function, becouse script must be saved as file before execution. If
		you forget that, copy of script will be saved in /tmp and removed later. Saving
		directly in /tmp directory is hightly discouraged.
	
	You should not use this class to just execute existing scripts because it
	makes a copy of the script. To do this use the StScriptFile class.
*/

const int ER_STSCRIPT_TEMP_FILE = 1;

class StScript : public StApplication, public StStringList
{
	public:
		StScript(){ setShell(ST_DEFAULT_SHELL); }
		StScript( const StString& fileName ) { load( fileName ); StScript(); }
		~StScript(){}
		
		/** Load script from file. This erases prefious loaded script. */
		bool load( StFile file ) { clear(); return StStringList::load( file ); }
		
		/** Set shell to execute script. It can be bash for bash scripts or php for php scripts */
		bool setShell( const StFile& shell ) { return StApplication::setExecutable( shell ); }
		void setArguments( const StStringList& args ) { this->args = args; }
		void setArguments( const StString& str ) { setArguments( StStringList() << str ); }
		
		bool execute( bool wait=true, bool outputToFile=true );
		
		void clear() { StStringList::clear(); }
		
	private:
		//StFile scriptFile;
		StStringList args;
		
		/// Disallow of use this function couse of possible missunderstand
		bool setExecutable( const StFile& file ){ return true; }
		
};

#endif //SMART_TOOLS_SCRIPT_H

